#version 150

#moj_import <fog.glsl>
#moj_import <emissive_handler.glsl>
#moj_import <health_bar_handler.glsl>
#moj_import <health_bar_animation.glsl>
#moj_import <health_bar_color.glsl>
#moj_import <health_bar_hitcolor.glsl>

uniform sampler2D Sampler0;

uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;
uniform float GameTime;

in float vertexDistance;
in vec4 vertexColor;
in vec4 lightMapColor;
in vec4 overlayColor;
in vec2 texCoord0;
in vec4 normal;

out vec4 fragColor;

void main() {
    vec4 color = texture(Sampler0, texCoord0);
	vec4 shading = ColorModulator*vertexColor;
	if (color.a < 0.1) {
        discard;
    }
	
	float alpha = textureLod(Sampler0, texCoord0, 0.0).a * 255.0;
    
	color = emissive_handler(color, shading, alpha);
	
	if(check_healthbar(alpha) == -1.0) {
	    color /= vertexColor;
		color.a = 255.0; 
	} 
	
	if(check_healthbar(alpha) == 1.0) {
	    color = health_color(color,shading,vertexColor,alpha);
	    color = health_animation(color,overlayColor,alpha,GameTime);
	    color = health_hitcolor(color,overlayColor,alpha,GameTime);
	    color.a = 255.0;
	}
	
	if(check_healthbar(alpha) == 0.0) color.rgb = mix(overlayColor.rgb, color.rgb, overlayColor.a);

    color *= lightMapColor;
	
    if(check_healthbar(alpha) == 0.0) fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
    if(check_healthbar(alpha) == 1.0 || check_healthbar(alpha) == -1.0) {
	    if(vec3(FogColor.r,FogColor.g,FogColor.b) == vec3(0.0,0.0,0.0)) {
	    fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
	    } else {
	    fragColor = color;
	    }
	} 
}
